@@ -1,25 +1,73 @@
 use crate::output_logger_provider_base_py::OutputLoggerProviderBasePy;
-use crate::pyo_utils::py_dict_to_map;
 use crate::statsig_persistent_storage_override_adapter_py::{
     PersistentStorageBasePy, StatsigPersistentStorageOverrideAdapter,
 };
+use crate::valid_primitives_py::ValidPrimitivesPy;
 use crate::{
     data_store_base_py::DataStoreBasePy, observability_client_base_py::ObservabilityClientBasePy,
 };
 use pyo3::prelude::*;
-use pyo3::types::PyDict;
+use pyo3::types::PyList;
 use pyo3_stub_gen::derive::*;
 use statsig_rust::data_store_interface::DataStoreTrait;
 use statsig_rust::networking::proxy_config::ProxyConfig;
 use statsig_rust::output_logger::OutputLogProvider;
-use statsig_rust::{log_w, ConfigCompressionMode, PersistentStorage};
+use statsig_rust::statsig_options::DEFAULT_INIT_TIMEOUT_MS;
+use statsig_rust::{log_w, ConfigCompressionMode, PersistentStorage, SpecAdapterConfig};
 use statsig_rust::{output_logger::LogLevel, ObservabilityClient, StatsigOptions};
+use std::collections::HashMap;
 use std::sync::{Arc, Weak};
 
 const TAG: &str = stringify!(StatsigOptionsPy);
 
 #[gen_stub_pyclass]
-#[pyclass(name = "ProxyConfig")]
+#[pyclass(name = "SpecAdapterConfig", module = "statsig_python_core")]
+#[derive(Clone)]
+pub struct SpecAdapterConfigPy {
+    #[pyo3(get, set)]
+    pub adapter_type: String,
+
+    #[pyo3(get, set)]
+    pub specs_url: Option<String>,
+
+    #[pyo3(get, set)]
+    pub init_timeout_ms: Option<u64>,
+}
+
+#[pymethods]
+impl SpecAdapterConfigPy {
+    #[new]
+    #[pyo3(signature = (adapter_type, specs_url=None, init_timeout_ms=None))]
+    pub fn new(
+        adapter_type: String,
+        specs_url: Option<String>,
+        init_timeout_ms: Option<u64>,
+    ) -> Self {
+        Self {
+            adapter_type,
+            specs_url,
+            init_timeout_ms,
+        }
+    }
+}
+
+impl From<SpecAdapterConfigPy> for SpecAdapterConfig {
+    fn from(value: SpecAdapterConfigPy) -> Self {
+        Self {
+            adapter_type: value.adapter_type.into(),
+            init_timeout_ms: value.init_timeout_ms.unwrap_or(DEFAULT_INIT_TIMEOUT_MS),
+            specs_url: value.specs_url,
+            authentication_mode: None,
+            ca_cert_path: None,
+            client_cert_path: None,
+            domain_name: None,
+            client_key_path: None,
+        }
+    }
+}
+
+#[gen_stub_pyclass]
+#[pyclass(name = "ProxyConfig", module = "statsig_python_core")]
 #[derive(Clone)]
 pub struct ProxyConfigPy {
     #[pyo3(get, set)]
@@ -53,7 +101,7 @@ impl ProxyConfigPy {
 }
 
 #[gen_stub_pyclass]
-#[pyclass(name = "StatsigOptions")]
+#[pyclass(name = "StatsigOptions", module = "statsig_python_core")]
 #[derive(FromPyObject, Default)]
 pub struct StatsigOptionsPy {
     #[pyo3(get, set)]
@@ -95,7 +143,7 @@ pub struct StatsigOptionsPy {
     #[pyo3(get, set)]
     pub output_log_level: Option<String>,
     #[pyo3(get, set)]
-    pub global_custom_fields: Option<Py<PyDict>>,
+    pub global_custom_fields: Option<HashMap<String, ValidPrimitivesPy>>,
     #[pyo3(get, set)]
     pub observability_client: Option<Py<ObservabilityClientBasePy>>,
     #[pyo3(get, set)]
@@ -108,6 +156,8 @@ pub struct StatsigOptionsPy {
     pub config_compression_mode: Option<String>,
     #[pyo3(get, set)]
     pub proxy_config: Option<Py<ProxyConfigPy>>,
+    #[pyo3(get, set)]
+    pub spec_adapter_configs: Option<Py<PyList>>,
 }
 
 #[gen_stub_pymethods]
@@ -141,6 +191,7 @@ impl StatsigOptionsPy {
         config_compression_mode=None,
         proxy_config=None,
         output_logger_provider=None,
+        spec_adapter_configs=None,
     ))]
     #[allow(clippy::too_many_arguments)]
     pub fn new(
@@ -163,13 +214,14 @@ impl StatsigOptionsPy {
         fallback_to_statsig_api: Option<bool>,
         environment: Option<String>,
         output_log_level: Option<String>,
-        global_custom_fields: Option<Py<PyDict>>,
+        global_custom_fields: Option<HashMap<String, ValidPrimitivesPy>>,
         observability_client: Option<Py<ObservabilityClientBasePy>>,
         data_store: Option<Py<DataStoreBasePy>>,
         persistent_storage: Option<Py<PersistentStorageBasePy>>,
         config_compression_mode: Option<String>,
         proxy_config: Option<Py<ProxyConfigPy>>,
         output_logger_provider: Option<Py<OutputLoggerProviderBasePy>>,
+        spec_adapter_configs: Option<Py<PyList>>,
     ) -> Self {
         Self {
             specs_url,
@@ -198,6 +250,7 @@ impl StatsigOptionsPy {
             config_compression_mode,
             proxy_config,
             output_logger_provider,
+            spec_adapter_configs,
         }
     }
 }
@@ -225,6 +278,16 @@ fn create_inner_statsig_options(
     opts: StatsigOptionsPy,
     ob_client_weak: Option<Weak<dyn ObservabilityClient>>,
 ) -> StatsigOptions {
+    let mut global_custom_fields = None;
+    if let Some(fields) = opts.global_custom_fields {
+        let converted = fields
+            .into_iter()
+            .map(|(k, v)| (k, v.into_dynamic_value()))
+            .collect();
+
+        global_custom_fields = Some(converted);
+    }
+
     StatsigOptions {
         specs_url: opts.specs_url.clone(),
         specs_adapter: None,
@@ -242,7 +305,6 @@ fn create_inner_statsig_options(
                     None
                 }
             }),
-        spec_adapters_config: None,
         log_event_url: opts.log_event_url.clone(),
         disable_all_logging: opts.disable_all_logging,
         event_logging_adapter: None,
@@ -264,10 +326,7 @@ fn create_inner_statsig_options(
         service_name: None,
         wait_for_user_agent_init: opts.wait_for_user_agent_init,
         wait_for_country_lookup_init: opts.wait_for_user_agent_init,
-        global_custom_fields: opts
-            .global_custom_fields
-            .as_ref()
-            .map(|dict| py_dict_to_map(dict.bind(py))),
+        global_custom_fields,
         disable_network: opts.disable_network,
         disable_country_lookup: opts.disable_country_lookup,
         disable_user_agent_parsing: opts.disable_user_agent_parsing,
@@ -294,6 +353,12 @@ fn create_inner_statsig_options(
                 }
             }
         }),
+        spec_adapters_config: opts.spec_adapter_configs.and_then(|configs| {
+            match configs.extract::<Vec<SpecAdapterConfigPy>>(py) {
+                Ok(configs) => Some(configs.into_iter().map(|config| config.into()).collect()),
+                Err(_) => None,
+            }
+        }),
         output_logger_provider: opts.output_logger_provider.as_ref().map(|provider| {
             Arc::new(
                 provider
